==> freecad_0.16.6712+dfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>CmdCreateSpreadsheet</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create a new spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom-align contents of selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center-align contents of selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left-align contents of selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right-align contents of selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top-align contents of selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertically center-align</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center-align contents vertically of selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetExport</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export spreadsheet to CSV file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetImport</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import CSV file into spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merge cells</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merge selected cells in spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set alias for selected cell</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Split cell</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Split previously merged cells in spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bold text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set bold text in selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set italic text in selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set underline text in selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColorPickerPopup</name>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <source>Cell properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Display unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unit string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A&amp;lias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alias for this cell</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cell contents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtColorPicker</name>
    <message>
        <source>Black</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>White</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Magenta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark magenta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Sheet</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Contents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpreadsheetGui::Module</name>
    <message>
        <source>Unnamed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
        <source>Insert rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert columns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove columns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Properties...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>CmdCreateSpreadsheet</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create a new spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom-align contents of selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center-align contents of selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left-align contents of selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right-align contents of selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Align top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top-align contents of selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertically center-align</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertically center-align contents of selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetExport</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export spreadsheet to CSV file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetImport</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import CSV file into spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merge cells</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merge selected cells in spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set alias for selected cell</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Split cell</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Split previously merged cells in spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bold text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set bold text in selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set italic text in selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline text in selected cells</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ColorPickerPopup</name>
    <message>
        <source>Custom Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <source>Cell properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Alignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Display unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unit string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A&amp;lias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alias for this cell</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>All (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cell contents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set cell(s) foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the Spreadsheet cell(s) foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set cell(s) background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the Spreadsheet cell(s) background color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtColorPicker</name>
    <message>
        <source>Black</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>White</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Magenta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark magenta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dark gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Sheet</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Contents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpreadsheetGui::Module</name>
    <message>
        <source>Unnamed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
        <source>Insert rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert columns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove columns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Properties...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <source>Spreadsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
